@@ -64,6 +64,7 @@
 #define CDRDAO_NA ": n/a"
 #define CDRDAO_CD "CD"
 
+/*
 static gchar *get_blank_type(Tgrave *Ag, gint Atypemedia)
 {
   gboolean *Luseautoblank = (gboolean *) sc_grave_get_data(Ag, "useautoblank");
@@ -71,7 +72,7 @@ static gchar *get_blank_type(Tgrave *Ag, gint Atypemedia)
   if (!*Luseautoblank || (!(Atypemedia & _MEDIA_CDRW))) return g_strdup("");
 
   return g_strdup_printf("blank=%s", conf_get_boolean("fastblank") == TRUE ? "fast" : "all");
-}
+}*/
 
 /* callback appele lorsque cdrdao grave les pistes */
 gboolean cdrdao_grave_callback(GIOChannel *Astd, GIOCondition Acond, gpointer Adata)
@@ -158,7 +159,7 @@ _DEB("===>%s", Lbuffer);
         maj_progress(Lprogressbar2, Lpct);
 
         /* avancement total */
-        Ltava = (1.0/ (*Ltodo)) * ((*Ldone)-1+Lpct);
+        Ltava = (1.0/ (*Ltodo)) * ((*Ldone)+Lpct);
         maj_progress(Lprogressbar, Ltava);
 
         /* barre fifo */
@@ -298,15 +299,12 @@ gboolean copycd(Tgrave *Ag, GError **Aerror) {
   gint Lcurcd;
   gboolean Ldosimul;
   gint Lnbrpass=1;
-  gchar *Lblank;
   gboolean Leject = FALSE;
   gchar Latspeed[_BUF_SIZE]; /* vitesse reel de l'operation */
   gchar Llasttrack[_BUF_SIZE]; /* derniere piste traite */
   glong Llength; /* longueur total du cd */
-  gint Lmediadetect1 = _MEDIA_CDRW;
 
   Lbufvitesse = get_combo_value(Lvitesse);
-  Lblank = get_blank_type(Ag, Lmediadetect1);
 
   *Ltodo = ((Lnbrgravure * 2 ) + (Lsimul ? 2 : 0) + (Lonfly ? Lnbrgravure : 0));
 
@@ -326,25 +324,36 @@ gboolean copycd(Tgrave *Ag, GError **Aerror) {
     if (Lcurcd > 1 && !Ldosimul) {
       /* copie sur un nouveau cd, on demande a l'utilisateur d'inserer le
        * nouveau cd vierge */
-      GSList *Llmediarequis = g_slist_append(NULL, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_APPENDABLE));
+
+      GSList *Llmediarequis2 = sc_grave_get_data(Ag, "mediarequis2");
+      gint *Lmediatitle2 = sc_grave_get_data(Ag, "mediatitle2");
+      gchar *Ltxt = sc_grave_get_data(Ag, "medialabel");
       gboolean Lstatus;
-      Llmediarequis = g_slist_append(Llmediarequis, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_APPENDABLE));
-
-/*      gint Lrep;
-      GtkWidget *Lconfirm = gtk_message_dialog_new(Lwindow,
-                                              GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
-                                              GTK_BUTTONS_YES_NO,
-                 _("Now you should insert next CD-R, do you want to continue operation ?"));
-      Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
-      gtk_widget_destroy(Lconfirm);
-      if (Lrep == GTK_RESPONSE_NO) {*/
-      Lstatus = waiting_for_user(_MEDIA_BLANKORAPPENDABLE, Ag, Llmediarequis, &Lmediadetect1, Lgraveur);
-      g_slist_free(Llmediarequis);
+      Tgrave *Ldialoghash;
+      GtkWidget *Lconfirm;
+      gint Lrep;
 
+      /*
+       * TODO : FAIRE UNE BELLE FONCTION DE CODE DUPLIQUE UN BON PAQUET DE FOIS #@!!
+       */ 
+      eject_cd(DRIVE_DEV(Lgraveur), NULL);
+      Lstatus = waiting_for_user(*Lmediatitle2, Ag, Llmediarequis2 , NULL, Lgraveur);
+          
       if (Lstatus==FALSE) {
         /* si c'est non alors on arrete */
-        *Labort = TRUE;
-        Lstatus = TRUE;
+        *Labort = TRUE; Lstatus = TRUE; break;
+      } 
+      
+      Ldialoghash = create_dialog_confirm_operation(GTK_WIDGET(Lwindow), Ltxt, NULL, FALSE);
+
+      Lconfirm = sc_grave_get_data(Ldialoghash, "window");
+      Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
+      gtk_widget_destroy(Lconfirm);
+
+      if (Lrep != GTK_RESPONSE_YES) {
+        /* si c'est non alors on arrete */
+        *Labort = TRUE; Lstatus = TRUE;
+        break;
       }
     }
 
@@ -454,7 +463,6 @@ _DEB("execution [%s]\n", Lcommandline);
     (*Ldone)++;
   }
 
-  g_free(Lblank);
   g_free(Lbufvitesse);
 
   sc_grave_del_data(Ag, "simul");
